# Rankability Toolbox
This repo contains various implementations that provide insights into the rankability of data and the linear ordering problem.

# Install instructions
## Prerequisites
graphviz headers must be installed:
```bash
sudo apt-get install -y libgraphviz-dev
```

## Notes on running tests
```bash
cd ranking_toolbox
python3 -m venv ../env
source ../env/bin/activate
cd tests
pytest tests.py
```

## Authors
Paul Anderson, Ph.D.<br>
Department of Computer Science<br>
Director, Data Science Program<br>
College of Charleston<br>

Amy Langville, Ph.D.<br>
Department of Mathematics<br>
College of Charleston<br>

Tim Chartier, Ph.D.<br>
Department of Mathematics<br>
Davidson College

## Acknowledgements
We would like to thank the entire IGARDS team for their invaluable insight and encouragement.

